@@ -1,5 +1,6 @@
 
-import os, _orekit
+import os
+from . import _orekit
 
 __dir__ = os.path.abspath(os.path.dirname(__file__))
 
@@ -16,11 +17,11 @@ class InvalidArgsError(Exception):
 
 _orekit._set_exception_types(JavaError, InvalidArgsError)
 
-VERSION = "9.0"
-CLASSPATH = [os.path.join(__dir__, "orekit-9.0.jar"), os.path.join(__dir__, "hipparchus-core-1.1.jar"), os.path.join(__dir__, "hipparchus-fitting-1.1.jar"), os.path.join(__dir__, "hipparchus-geometry-1.1.jar"), os.path.join(__dir__, "hipparchus-ode-1.1.jar"), os.path.join(__dir__, "hipparchus-optim-1.1.jar"), os.path.join(__dir__, "hipparchus-stat-1.1.jar")]
+VERSION = "9.1"
+CLASSPATH = [os.path.join(__dir__, "orekit-9.1.jar"), os.path.join(__dir__, "hipparchus-core-1.2.jar"), os.path.join(__dir__, "hipparchus-fitting-1.2.jar"), os.path.join(__dir__, "hipparchus-geometry-1.2.jar"), os.path.join(__dir__, "hipparchus-ode-1.2.jar"), os.path.join(__dir__, "hipparchus-optim-1.2.jar"), os.path.join(__dir__, "hipparchus-stat-1.2.jar")]
 CLASSPATH = os.pathsep.join(CLASSPATH)
 _orekit.CLASSPATH = CLASSPATH
 _orekit._set_function_self(_orekit.initVM, _orekit)
 
-from _orekit import *
+from ._orekit import *
 from java.io import PrintWriter, StringWriter
